@@ -9,5 +9,5 @@ var (
 	DBRecoveryTimeout        = 24 * time.Hour
 	DBRecoveryRetryBackoff   = 200 * time.Millisecond
 	ServicePingInterval      = 50 * time.Millisecond
-	PluginStartTimeout       = 30 * time.Second
+	PluginStartTimeout       = 3 * time.Minute
 )
