@@ -7,6 +7,7 @@ const (
 	ExitCodePluginLoadingError          = 11  // plugin - loading error
 	ExitCodePluginListFailure           = 12  // plugin - listing failed
 	ExitCodePluginNotFound              = 13  // plugin - not found
+	ExitCodePluginInstallFailure        = 14  // plugin - install failed
 	ExitCodeSnapshotCreationFailed      = 21  // snapshot - creation failed
 	ExitCodeSnapshotUploadFailed        = 22  // snapshot - upload failed
 	ExitCodeServiceSetupFailure         = 31  // service - setup failed
@@ -14,6 +15,8 @@ const (
 	ExitCodeServiceStopFailure          = 33  // service - stop failed
 	ExitCodeQueryExecutionFailed        = 41  // query - 1 or more queries failed - change in behavior(previously the exitCode used to be the number of queries that failed)
 	ExitCodeLoginCloudConnectionFailed  = 51  // login - connecting to cloud failed
+	ExitCodeModInitFailed               = 61  // mod - init failed
+	ExitCodeModInstallFailed            = 62  // mod - install failed
 	ExitCodeInvalidExecutionEnvironment = 249 // common - when steampipe is run in an unsupported environment
 	ExitCodeInitializationFailed        = 250 // common - initialization failed
 	ExitCodeBindPortUnavailable         = 251 // common(service/dashboard) - port binding failed
