@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"log"
 	"net/netip"
+	"slices"
 	"strings"
 	"time"
 
@@ -13,15 +14,14 @@ import (
 	"github.com/jackc/pgx/v5"
 	"github.com/jackc/pgx/v5/pgtype"
 	"github.com/spf13/viper"
-	"github.com/turbot/go-kit/helpers"
-	pconstants "github.com/turbot/pipe-fittings/constants"
-	pqueryresult "github.com/turbot/pipe-fittings/queryresult"
-	"github.com/turbot/pipe-fittings/utils"
-	"github.com/turbot/steampipe/pkg/constants"
-	"github.com/turbot/steampipe/pkg/db/db_common"
-	"github.com/turbot/steampipe/pkg/error_helpers"
-	"github.com/turbot/steampipe/pkg/query/queryresult"
-	"github.com/turbot/steampipe/pkg/statushooks"
+	pconstants "github.com/turbot/pipe-fittings/v2/constants"
+	pqueryresult "github.com/turbot/pipe-fittings/v2/queryresult"
+	"github.com/turbot/pipe-fittings/v2/utils"
+	"github.com/turbot/steampipe/v2/pkg/constants"
+	"github.com/turbot/steampipe/v2/pkg/db/db_common"
+	"github.com/turbot/steampipe/v2/pkg/error_helpers"
+	"github.com/turbot/steampipe/v2/pkg/query/queryresult"
+	"github.com/turbot/steampipe/v2/pkg/statushooks"
 	"golang.org/x/text/language"
 	"golang.org/x/text/message"
 )
@@ -402,7 +402,7 @@ func populateRow(columnValues []interface{}, cols []*pqueryresult.ColumnDef) ([]
 func isStreamingOutput() bool {
 	outputFormat := viper.GetString(pconstants.ArgOutput)
 
-	return helpers.StringSliceContains([]string{constants.OutputFormatCSV, constants.OutputFormatLine}, outputFormat)
+	return slices.Contains([]string{constants.OutputFormatCSV, constants.OutputFormatLine}, outputFormat)
 }
 
 func humanizeRowCount(count int) string {
