@@ -3,8 +3,8 @@ package db_common
 import (
 	"context"
 
-	"github.com/turbot/pipe-fittings/utils"
-	"github.com/turbot/steampipe/pkg/query/queryresult"
+	"github.com/turbot/pipe-fittings/v2/utils"
+	"github.com/turbot/steampipe/v2/pkg/query/queryresult"
 )
 
 // ExecuteQuery executes a single query. If shutdownAfterCompletion is true, shutdown the client after completion
