@@ -5,9 +5,9 @@ import (
 	"fmt"
 
 	"github.com/spf13/viper"
-	pconstants "github.com/turbot/pipe-fittings/constants"
-	"github.com/turbot/steampipe/pkg/constants"
-	"github.com/turbot/steampipe/pkg/error_helpers"
+	pconstants "github.com/turbot/pipe-fittings/v2/constants"
+	"github.com/turbot/steampipe/v2/pkg/constants"
+	"github.com/turbot/steampipe/v2/pkg/error_helpers"
 )
 
 type InitResult struct {
