@@ -2,8 +2,8 @@ package db_common
 
 import (
 	"github.com/spf13/viper"
-	pconstants "github.com/turbot/pipe-fittings/constants"
-	"github.com/turbot/steampipe/pkg/constants"
+	pconstants "github.com/turbot/pipe-fittings/v2/constants"
+	"github.com/turbot/steampipe/v2/pkg/constants"
 )
 
 func MaxDbConnections() int {
