@@ -5,8 +5,8 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/turbot/pipe-fittings/steampipeconfig"
-	"github.com/turbot/steampipe/pkg/constants"
+	"github.com/turbot/pipe-fittings/v2/steampipeconfig"
+	"github.com/turbot/steampipe/v2/pkg/constants"
 )
 
 type SnapshotExporter struct {
