@@ -3,9 +3,9 @@ package introspection
 import (
 	"fmt"
 
-	"github.com/turbot/pipe-fittings/plugin"
-	"github.com/turbot/steampipe/pkg/constants"
-	"github.com/turbot/steampipe/pkg/db/db_common"
+	"github.com/turbot/pipe-fittings/v2/plugin"
+	"github.com/turbot/steampipe/v2/pkg/constants"
+	"github.com/turbot/steampipe/v2/pkg/db/db_common"
 )
 
 func GetRateLimiterTableCreateSql() db_common.QueryWithArgs {
