@@ -7,15 +7,15 @@ import (
 
 	"github.com/hashicorp/go-plugin"
 	typehelpers "github.com/turbot/go-kit/types"
-	pconstants "github.com/turbot/pipe-fittings/constants"
-	"github.com/turbot/pipe-fittings/modconfig"
-	"github.com/turbot/pipe-fittings/utils"
+	pconstants "github.com/turbot/pipe-fittings/v2/constants"
+	"github.com/turbot/pipe-fittings/v2/modconfig"
+	"github.com/turbot/pipe-fittings/v2/utils"
 	sdkgrpc "github.com/turbot/steampipe-plugin-sdk/v5/grpc"
 	sdkproto "github.com/turbot/steampipe-plugin-sdk/v5/grpc/proto"
 	sdkplugin "github.com/turbot/steampipe-plugin-sdk/v5/plugin"
-	"github.com/turbot/steampipe/pkg/error_helpers"
-	"github.com/turbot/steampipe/pkg/pluginmanager_service/grpc/proto"
-	pluginshared "github.com/turbot/steampipe/pkg/pluginmanager_service/grpc/shared"
+	"github.com/turbot/steampipe/v2/pkg/error_helpers"
+	"github.com/turbot/steampipe/v2/pkg/pluginmanager_service/grpc/proto"
+	pluginshared "github.com/turbot/steampipe/v2/pkg/pluginmanager_service/grpc/shared"
 	"golang.org/x/exp/maps"
 )
 
@@ -286,7 +286,7 @@ func createConnectionPlugin(connection *modconfig.SteampipeConnection, reattach
 	// we must have a plugin instance
 	if connection.PluginInstance == nil {
 		// unexpected
-		return nil, fmt.Errorf(fmt.Sprintf("connection '%s' has no plugin instance", connection.Name))
+		return nil, fmt.Errorf("%s", fmt.Sprintf("connection '%s' has no plugin instance", connection.Name))
 	}
 
 	log.Printf("[TRACE] createConnectionPlugin for connection %s", connection.Name)
